Video Input and Output (videoio module) {#tutorial_table_of_content_videoio}
=========================================

This section contains tutorials about how to read/save your video files.

-   @subpage tutorial_video_input_psnr_ssim

    *Languages:* C++, Python

    *Compatibility:* \> OpenCV 2.0

    *Author:* Bernát Gábor

    You will learn how to read video streams, and how to calculate similarity values such as PSNR
    or SSIM.

-   @subpage tutorial_video_write

    *Languages:* C++

    *Compatibility:* \> OpenCV 2.0

    *Author:* Bernát Gábor

-   @subpage tutorial_kinect_openni

    *Languages:* C++

-   @subpage tutorial_intelperc

    *Languages:* C++